#!/usr/bin/env python

# Copyright (c) me.
# Distributed under the terms of the Modified BSD License.

"""
TODO: Add module docstring
"""

from ipywidgets import DOMWidget
from traitlets import Unicode

from ._frontend import module_name, module_version


class ExampleWidget(DOMWidget):
    """TODO: Add docstring here"""

    _model_name = Unicode("ExampleModel").tag(sync=True)
    _model_module = Unicode(module_name).tag(sync=True)
    _model_module_version = Unicode(module_version).tag(sync=True)
    _view_name = Unicode("ExampleView").tag(sync=True)
    _view_module = Unicode(module_name).tag(sync=True)
    _view_module_version = Unicode(module_version).tag(sync=True)

    value = Unicode("Hello World").tag(sync=True)



import os
import platform
import subprocess
import sys
import venv
import warnings
from pathlib import Path

import pytest
from hatchling.metadata.core import ProjectMetadata
from hatchling.plugin.manager import PluginManager

from hatch_jupyter_builder.plugin import JupyterBuildHook


def test_build_hook(tmp_path):
    manager = PluginManager()
    meta = ProjectMetadata(".", manager, {})

    if "SKIP_JUPYTER_BUILD" in os.environ:
        del os.environ["SKIP_JUPYTER_BUILD"]

    config = {
        "build-function": "test.foo",
        "ensured-targets": ["test.py"],
        "build-kwargs": {"foo-bar": "1", "fizz_buzz": "2"},
        "install-pre-commit-hook": True,
    }
    os.chdir(tmp_path)
    test = Path("test.py")
    text = """
def foo(target_name, version, foo_bar=None, fizz_buzz=None):
    return(target_name)
"""
    test.write_text(text, encoding="utf-8")
    os.makedirs(".git/hooks")

    hook = JupyterBuildHook(tmp_path, config, {}, meta, tmp_path, "wheel")
    assert hook.initialize("standard", {})
    assert hook.initialize("editable", {})

    hook = JupyterBuildHook(tmp_path, config, {}, meta, tmp_path, "sdist")
    assert hook.initialize("standard", {})

    hook = JupyterBuildHook(tmp_path, {}, {}, meta, tmp_path, "wheel")
    assert hook.initialize("standard", {})
    assert hook.initialize("editable", {})

    config["skip-if-exists"] = ["foo", "bar"]
    assert hook.initialize("standard", {})
    del config["skip-if-exists"]

    config["editable-build-kwargs"] = {"foo-bar": "2", "fizz_buzz": "3"}
    assert hook.initialize("editable", {})

    hook = JupyterBuildHook(tmp_path, config, {}, meta, tmp_path, "foo")
    assert not hook.initialize("standard", {})

    text = """
def foo(target_name, version, foo_bar=None, fizz_buzz=None):
    raise RuntimeError('trigger error')
"""
    test.write_text(text, encoding="utf-8")
    # Force a re-import
    del sys.modules["test"]

    hook = JupyterBuildHook(tmp_path, config, {}, meta, tmp_path, "wheel")
    with pytest.raises(RuntimeError):
        hook.initialize("editable", {})

    os.environ["SKIP_JUPYTER_BUILDER"] = "1"
    assert not hook.initialize("standard", {})
    del os.environ["SKIP_JUPYTER_BUILDER"]

    config["optional-editable-build"] = "true"
    hook = JupyterBuildHook(tmp_path, config, {}, meta, tmp_path, "wheel")
    with warnings.catch_warnings():
        warnings.simplefilter("ignore")
        assert hook.initialize("editable", {})

    config["optional-editable-build"] = True
    hook = JupyterBuildHook(tmp_path, config, {}, meta, tmp_path, "wheel")
    with warnings.catch_warnings():
        warnings.simplefilter("ignore")
        assert hook.initialize("editable", {})

    del sys.modules["test"]


HERE = Path(__file__).parent
REPO_ROOT = str(HERE.parent).replace(os.sep, "/")
TOML_CONTENT = f"""
[build-system]
requires = ["hatchling>=1.0"]
build-backend = "hatchling.build"

[project]
name = "test"
version = "0.6.0"

[tool.hatch.build.hooks.jupyter-builder]
dependencies = ["hatch-jupyter-builder@file://{REPO_ROOT}"]
"""


@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="Does not work on PyPy")
def test_hatch_build(tmp_path):
    venv.create(tmp_path, with_pip=True)
    if os.name == "nt":
        python = Path(tmp_path) / "Scripts/python.exe"
    else:
        python = Path(tmp_path) / "bin/python"
    pyproject = Path(tmp_path) / "pyproject.toml"
    pyproject.write_text(TOML_CONTENT, "utf-8")
    test = Path(tmp_path) / "test.py"
    test.write_text("print('hello')", "utf-8")
    env = os.environ.copy()
    # Handle running min version test.
    if "PIP_CONSTRAINT" in env:
        del env["PIP_CONSTRAINT"]
    subprocess.check_call([python, "-m", "pip", "install", "build"], cwd=tmp_path, env=env)

    subprocess.check_call([python, "-m", "build", "--sdist", "."], cwd=tmp_path, env=env)



#!/usr/bin/env python

# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.


import os
from glob import glob
from os.path import join as pjoin

from jupyter_packaging import (
    combine_commands,
    create_cmdclass,
    ensure_targets,
    get_version,
    install_npm,
    skip_if_exists,
)
from setuptools import find_packages, setup

HERE = os.path.dirname(os.path.abspath(__file__))


# The name of the project
name = "myproject"

# Get the version
version = get_version(pjoin(name, "_version.py"))


# Representative files that should exist after a successful build
jstargets = [
    pjoin(HERE, name, "nbextension", "index.js"),
    pjoin(HERE, name, "labextension", "package.json"),
]


package_data_spec = {name: ["nbextension/**js*", "labextension/**"]}


data_files_spec = [
    ("share/jupyter/nbextensions/myproject", "myproject/nbextension", "**"),
    ("share/jupyter/labextensions/myproject", "myproject/labextension", "**"),
    ("share/jupyter/labextensions/myproject", ".", "install.json"),
    ("etc/jupyter/nbconfig/notebook.d", ".", "myproject.json"),
]


cmdclass = create_cmdclass(
    "jsdeps", package_data_spec=package_data_spec, data_files_spec=data_files_spec
)
npm_install = combine_commands(
    install_npm(HERE, build_cmd="build:prod"),
    ensure_targets(jstargets),
)
cmdclass["jsdeps"] = skip_if_exists(jstargets, npm_install)


setup_args = dict(
    name=name,
    description="A Custom Jupyter Widget Library",
    version=version,
    scripts=glob(pjoin("scripts", "*")),
    cmdclass=cmdclass,
    packages=find_packages(),
    author="me",
    author_email="me@me.com",
    url="https://github.com/myorg/myproject",
    license="BSD",
    platforms="Linux, Mac OS X, Windows",
    keywords=["Jupyter", "Widgets", "IPython"],
    classifiers=[
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Framework :: Jupyter",
    ],
    include_package_data=True,
    python_requires=">=3.6",
    install_requires=[
        "ipywidgets>=7.0.0",
    ],
    extras_require={
        "test": [
            "pytest>=4.6",
            "pytest-cov",
            "nbval",
        ],
        "examples": [
            # Any requirements for the examples to run
        ],
        "docs": [
            "jupyter_sphinx",
            "nbsphinx",
            "nbsphinx-link",
            "pytest_check_links",
            "pypandoc",
            "recommonmark",
            "sphinx>=1.5",
            "sphinx_rtd_theme",
        ],
    },
    entry_points={},
)

if __name__ == "__main__":
    setup(**setup_args)



"""Compare the dist file created by a migrated package to one created by the original."""
import argparse
import glob
import logging
import os
import shutil
import subprocess
import sys
import tarfile
import zipfile
from typing import Optional


def build_file(dirname, dist_name):
    """Build a dist file in a directory."""
    orig_dir = os.getcwd()
    os.chdir(dirname)
    if os.path.exists("dist"):
        shutil.rmtree("dist")
    subprocess.check_call([sys.executable, "-m", "build", f"--{dist_name}"])
    os.chdir(orig_dir)


def get_tar_names(dirname):
    """Get the tarball names in a directory."""
    dist_file = glob.glob(f"{dirname}/dist/*.tar.gz")[0]
    tarf = tarfile.open(dist_file, "r:gz")
    return set(tarf.getnames())


def get_zip_names(dirname):
    """Get the zip (wheel) file names in a directory."""
    wheel_file = glob.glob(f"{dirname}/dist/*.whl")[0]
    with zipfile.ZipFile(wheel_file, "r") as f:
        return set(f.namelist())


def filter_file(path):
    """Filter a file path for interesting files."""
    if "egg-info" in path:
        return True
    _, ext = os.path.splitext(path)
    if not ext:
        return True
    if os.path.basename(path) in [path, "setup.py", "setup.cfg", "MANIFEST.in"]:
        return True
    return False


def main(source_dir, target_dir, dist_name):
    """The main script."""
    subprocess.check_call([sys.executable, "-m", "pip", "install", "build"])

    logger = logging.getLogger(__name__)
    logging.basicConfig()

    build_file(source_dir, dist_name)
    build_file(target_dir, dist_name)

    if dist_name == "sdist":
        source_names = get_tar_names(source_dir)
        target_names = get_tar_names(target_dir)
    else:
        source_names = get_zip_names(source_dir)
        target_names = get_zip_names(target_dir)

    removed = source_names - target_names
    removed = [r for r in removed if not filter_file(r)]
    if removed:
        logger.info("\nRemoved_files:")
        [logger.info(f) for f in removed]  # type:ignore

    added = target_names - source_names
    added = [a for a in added if not filter_file(a)]
    if added:
        logger.info("\nAdded files:")
        [logger.info(f) for f in added]  # type:ignore

    logger.info("")

    return {"added": added, "removed": removed}


def make_parser(
    parser: Optional[argparse.ArgumentParser] = None, prog: Optional[str] = None
) -> argparse.ArgumentParser:
    """Make an arg parser."""
    if parser is None:
        parser = argparse.ArgumentParser(prog=prog)
    parser.add_argument(dest="source_dir", help="Source Directory")
    parser.add_argument(dest="target_dir", help="Target Directory")
    parser.add_argument(dest="dist_name", help="Dist name")
    return parser


def run(args: Optional[argparse.Namespace] = None) -> None:
    """Run the cli."""
    if args is None:
        parser = make_parser(prog=f"{sys.executable} -m hatch_jupyter_builder.compare_migrated")
        args = parser.parse_args()
    main(args.source_dir, args.target_dir, args.dist_name)



import os
import sys
from unittest.mock import call

import pytest

from hatch_jupyter_builder import npm_builder


@pytest.fixture
def repo(tmp_path):
    os.makedirs(os.path.join(tmp_path, ".git"))
    os.chdir(tmp_path)
    return tmp_path


def test_npm_builder(mocker, repo):
    which = mocker.patch("hatch_jupyter_builder.utils.which")
    run = mocker.patch("hatch_jupyter_builder.utils.run")
    which.return_value = "foo"
    npm_builder("wheel", "standard", path=repo)
    run.assert_has_calls(
        [
            call(["foo", "install"], cwd=str(repo)),
            call(["foo", "run", "build"], cwd=str(repo)),
        ]
    )


def test_npm_build_skip(mocker, repo):
    which = mocker.patch("hatch_jupyter_builder.utils.which")
    run = mocker.patch("hatch_jupyter_builder.utils.run")
    os.environ["HATCH_JUPYTER_BUILDER_SKIP_NPM"] = "1"
    which.return_value = "foo"
    npm_builder("wheel", "standard", path=repo)
    run.assert_not_called()
    del os.environ["HATCH_JUPYTER_BUILDER_SKIP_NPM"]

    sys.argv = [*sys.argv, "--skip-npm"]
    npm_builder("wheel", "standard", path=repo)
    run.assert_not_called()


def test_npm_builder_yarn(mocker, repo):
    which = mocker.patch("hatch_jupyter_builder.utils.which")
    run = mocker.patch("hatch_jupyter_builder.utils.run")
    repo.joinpath("yarn.lock").write_text("hello")
    which.return_value = "foo"
    npm_builder("wheel", "standard", path=repo)
    run.assert_has_calls(
        [
            call(["foo", "install"], cwd=str(repo)),
            call(["foo", "run", "build"], cwd=str(repo)),
        ]
    )


def test_npm_builder_missing_yarn(mocker, repo):
    which = mocker.patch("hatch_jupyter_builder.utils.which")
    run = mocker.patch("hatch_jupyter_builder.utils.run")
    repo.joinpath("yarn.lock").write_text("hello")
    which.side_effect = ["", "foo"]
    npm_builder("wheel", "standard", path=repo)
    run.assert_has_calls(
        [
            call(["foo", "install"], cwd=str(repo)),
            call(["foo", "run", "build"], cwd=str(repo)),
        ]
    )


def test_npm_builder_path(mocker, tmp_path):
    which = mocker.patch("hatch_jupyter_builder.utils.which")
    run = mocker.patch("hatch_jupyter_builder.utils.run")
    which.return_value = "foo"
    npm_builder("wheel", "standard", path=tmp_path)
    run.assert_has_calls(
        [
            call(["foo", "install"], cwd=str(tmp_path)),
            call(["foo", "run", "build"], cwd=str(tmp_path)),
        ]
    )


def test_npm_builder_editable(mocker, repo):
    which = mocker.patch("hatch_jupyter_builder.utils.which")
    run = mocker.patch("hatch_jupyter_builder.utils.run")
    which.return_value = "foo"
    npm_builder("wheel", "editable", path=repo, editable_build_cmd="foo")
    run.assert_has_calls(
        [
            call(["foo", "install"], cwd=str(repo)),
            call(["foo", "run", "foo"], cwd=str(repo)),
        ]
    )


def test_npm_builder_npm_str(mocker, repo):
    which = mocker.patch("hatch_jupyter_builder.utils.which")
    run = mocker.patch("hatch_jupyter_builder.utils.run")
    which.return_value = "npm"
    npm_builder("wheel", "standard", path=repo, npm="npm")
    run.assert_has_calls(
        [
            call(["npm", "install"], cwd=str(repo)),
            call(["npm", "run", "build"], cwd=str(repo)),
        ]
    )


def test_npm_builder_npm_build_command_none(mocker, repo):
    which = mocker.patch("hatch_jupyter_builder.utils.which")
    run = mocker.patch("hatch_jupyter_builder.utils.run")
    which.return_value = "npm"
    npm_builder("wheel", "standard", path=repo, build_cmd=None)
    run.assert_has_calls([call(["npm", "install"], cwd=str(repo))])


def test_npm_builder_not_stale(mocker, repo):
    which = mocker.patch("hatch_jupyter_builder.utils.which")
    run = mocker.patch("hatch_jupyter_builder.utils.run")
    is_stale = mocker.patch("hatch_jupyter_builder.utils.is_stale")
    is_stale.return_value = False
    which.return_value = "foo"
    npm_builder("wheel", "standard", path=repo, build_dir=repo, source_dir=repo)
    run.assert_not_called()


def test_npm_builder_no_npm(mocker, repo):
    which = mocker.patch("hatch_jupyter_builder.utils.which")
    run = mocker.patch("hatch_jupyter_builder.utils.run")
    is_stale = mocker.patch("hatch_jupyter_builder.utils.is_stale")
    is_stale.return_value = False
    which.return_value = ""
    with pytest.raises(ValueError):
        npm_builder("wheel", "standard", path=repo)
    run.assert_not_called()



from pytest import fixture

from hatch_jupyter_builder import is_stale


@fixture
def source_dir(tmpdir):
    source = tmpdir.mkdir("source")
    source.join("file1.txt").write("original content")
    source.join("file2.txt").write("original content")
    sub = source.mkdir("sub")
    sub.join("subfile1.txt").write("original content")
    sub.join("subfile2.txt").write("original content")
    source.mkdir("node_modules")
    sub2 = source.mkdir("node_modules", "lol")
    sub2.join("index.js").write("use strict;")
    for p in source.visit():
        p.setmtime(10000)
    return source


@fixture
def destination_dir(tmpdir):
    destination = tmpdir.mkdir("destination")
    destination.join("file1.rtf").write("original content")
    destination.join("file2.rtf").write("original content")
    sub = destination.mkdir("sub")
    sub.join("subfile1.rtf").write("original content")
    sub.join("subfile2.rtf").write("original content")
    destination.mkdir("sub2")
    sub2 = destination.mkdir("sub2", "lol")
    sub2.join("static.html").write("<html><body>original content</body></html>")
    for p in destination.visit():
        p.setmtime(20000)
    return destination


def test_destination_is_not_stale(source_dir, destination_dir):
    assert is_stale(str(destination_dir), str(source_dir)) is False


def test_root_file_causes_stale(source_dir, destination_dir):
    source_dir.join("file1.txt").setmtime(30000)
    assert is_stale(str(destination_dir), str(source_dir)) is True


def test_sub_file_causes_stale(source_dir, destination_dir):
    source_dir.join("sub", "subfile2.txt").setmtime(30000)
    assert is_stale(str(destination_dir), str(source_dir)) is True


def test_folder_mtime_does_not_prevent_stale(source_dir, destination_dir):
    source_dir.join("sub", "subfile2.txt").setmtime(30000)
    destination_dir.setmtime(40000)
    destination_dir.join("sub").setmtime(40000)
    destination_dir.setmtime(40000)
    assert is_stale(str(destination_dir), str(source_dir)) is True


def test_folder_mtime_does_not_cause_stale(source_dir, destination_dir):
    source_dir.setmtime(40000)
    source_dir.join("sub").setmtime(40000)
    source_dir.setmtime(40000)
    assert is_stale(str(destination_dir), str(source_dir)) is False


# This behavior might not always be wanted?
# The alternative is to check whether ALL files in destination is newer
# than the newest file in source (more conservative).
def test_only_newest_files_determine_stale(source_dir, destination_dir):
    source_dir.join("file1.txt").setmtime(30000)
    destination_dir.join("file1.rtf").setmtime(40000)
    assert is_stale(str(destination_dir), str(source_dir)) is False


def test_unstale_on_equal(source_dir):
    assert is_stale(str(source_dir), str(source_dir)) is False


def test_file_vs_dir(source_dir, destination_dir):
    assert is_stale(str(destination_dir.join("file1.rtf")), str(source_dir)) is False
    source_dir.join("file2.txt").setmtime(30000)
    assert is_stale(str(destination_dir.join("file1.rtf")), str(source_dir)) is True


def test_dir_vs_file(source_dir, destination_dir):
    assert is_stale(str(destination_dir), str(source_dir.join("file1.txt"))) is False
    source_dir.join("file1.txt").setmtime(30000)
    assert is_stale(str(destination_dir), str(source_dir.join("file1.txt"))) is True


def test_file_vs_file(source_dir, destination_dir):
    assert (
        is_stale(str(destination_dir.join("file1.rtf")), str(source_dir.join("file1.txt"))) is False
    )
    source_dir.join("file1.txt").setmtime(30000)
    assert (
        is_stale(str(destination_dir.join("file1.rtf")), str(source_dir.join("file1.txt"))) is True
    )


def test_empty_dir(source_dir, tmpdir):
    empty_dir = tmpdir.mkdir("empty")
    assert is_stale(str(empty_dir), str(source_dir)) is True
    assert is_stale(str(source_dir), str(empty_dir)) is False
    assert is_stale(str(empty_dir), str(empty_dir)) is False


def test_missing_dir(source_dir, destination_dir):
    assert not is_stale(destination_dir, "does_not_exist")
    assert is_stale("does_not_exist", source_dir)



"""Migrate a Jupyter project from setuptools/jupyter-packaging to hatch and
hatch_jupyter_builder."""
import argparse
import logging
import os
import subprocess
import sys
import venv
from pathlib import Path
from tempfile import TemporaryDirectory
from typing import Optional

from hatch_jupyter_builder import __version__ as builder_version


def main(td, target_dir):
    """Main script."""
    logger = logging.getLogger(__name__)
    logging.basicConfig()
    venv.create(td, with_pip=True)
    python = Path(td) / "Scripts/python.exe" if os.name == "nt" else Path(td) / "bin/python"

    logger.info("Installing in temporary virtual environment...")

    # Create a virtual environment and use it to run the migration.
    runner = subprocess.check_call
    runner([python, "-m", "pip", "install", "build"])
    runner([python, "-m", "pip", "install", "packaging"])
    runner([python, "-m", "pip", "install", "tomli_w"])
    runner([python, "-m", "pip", "install", "tomli"])
    runner([python, "-m", "pip", "install", "hatch"])
    runner([python, "-m", "build", target_dir, "--sdist"])

    migrator = Path(__file__).parent / "_migrate.py"
    runner([python, migrator, builder_version], cwd=target_dir)


def make_parser(
    parser: Optional[argparse.ArgumentParser] = None, prog: Optional[str] = None
) -> argparse.ArgumentParser:
    """Make a parser object."""
    if parser is None:
        parser = argparse.ArgumentParser(prog=prog)
    parser.add_argument(dest="target_dir", help="Target Directory")
    return parser


def run(args: Optional[argparse.Namespace] = None) -> None:
    """Run the migration."""
    if args is None:
        parser = make_parser(prog=f"{sys.executable} -m hatch_jupyter_builder.migrate")
        args = parser.parse_args()
    with TemporaryDirectory() as td:
        main(td, args.target_dir)



#!/usr/bin/env python3
#
# myproject documentation build configuration file
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.


# -- General configuration ------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.viewcode",
    "sphinx.ext.intersphinx",
    "sphinx.ext.napoleon",
    "sphinx.ext.todo",
    "nbsphinx",
    "jupyter_sphinx",
    "nbsphinx_link",
]

# Set the nbsphinx JS path to empty to avoid showing twice of the widgets
nbsphinx_requirejs_path = ""
nbsphinx_widgets_path = ""

# Ensure our extension is available:
import sys
from os.path import dirname
from os.path import join as pjoin

docs = dirname(dirname(__file__))
root = dirname(docs)
sys.path.insert(0, root)
sys.path.insert(0, pjoin(docs, "sphinxext"))

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = ".rst"

# The master toctree document.
master_doc = "index"

# General information about the project.
project = "myproject"
copyright = "2022, me"
author = "me"

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.


# get version from python package:
import os

here = os.path.dirname(__file__)
repo = os.path.join(here, "..", "..")
_version_py = os.path.join(repo, "myproject", "_version.py")
version_ns = {}
with open(_version_py) as f:
    exec(f.read(), version_ns)  # noqa

# The short X.Y version.
version = "%i.%i" % version_ns["version_info"][:2]
# The full version, including alpha/beta/rc tags.
release = version_ns["__version__"]

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = ["**.ipynb_checkpoints"]

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = "sphinx"

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False


# -- Options for HTML output ----------------------------------------------


# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
# html_theme_options = {}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]


# -- Options for HTMLHelp output ------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = "myprojectdoc"


# -- Options for LaTeX output ---------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',
    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',
    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',
    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (master_doc, "myproject.tex", "myproject Documentation", "me", "manual"),
]


# -- Options for manual page output ---------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [(master_doc, "myproject", "myproject Documentation", [author], 1)]


# -- Options for Texinfo output -------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (
        master_doc,
        "myproject",
        "myproject Documentation",
        author,
        "myproject",
        "A Custom Jupyter Widget Library",
        "Miscellaneous",
    ),
]


# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {"https://docs.python.org/": None}

# Read The Docs
# on_rtd is whether we are on readthedocs.org, this line of code grabbed from
# docs.readthedocs.org
on_rtd = os.environ.get("READTHEDOCS", None) == "True"

if not on_rtd:  # only import and set the theme if we're building docs locally
    import sphinx_rtd_theme

    html_theme = "sphinx_rtd_theme"
    html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]

# otherwise, readthedocs.org uses their theme by default, so no need to specify it


# Uncomment this line if you have know exceptions in your included notebooks
# that nbsphinx complains about:
#
nbsphinx_allow_errors = True  # exception ipstruct.py ipython_genutils

from sphinx.util import logging

logger = logging.getLogger(__name__)


def setup(app):
    def add_scripts(app):
        for fname in ["helper.js", "embed-bundle.js"]:
            if not os.path.exists(os.path.join(here, "_static", fname)):
                logger.warning("missing javascript file: %s" % fname)
            app.add_js_file(fname)

    app.connect("builder-inited", add_scripts)
